@@ -10,7 +10,6 @@ from django.utils.functional import Promise
 from django.utils.html import linebreaks, mark_safe
 from django.utils.translation import gettext_lazy as _
 
-from . import layout
 from .settings.required import HTML_FALSE, HTML_NONE, HTML_TRUE
 
 
@@ -79,15 +78,9 @@ def as_download(value, label=None):
     if label is None:
         label = hg.SPAN(os.path.basename(value.name))
     return hg.A(
-        layout.icon.Icon(
-            "launch",
-            size=16,
-            style="vertical-align: middle; margin-right: 0.25rem;",
-        ),
         label,
         newtab=True,
         href=value.url,
-        style="margin-right: 0.5rem; margin-left: 0.5rem",
         onclick="event.stopPropagation();",
     )
 
